import {TextMessage} from "./message/TextMessage";
import {FileMessage} from "./message/FileMessage";
import {AudioMessage} from "./message/AudioMessage";
import {IconMessage} from "./message/IconMessage";

export type LinkUpEvents = {
    /**
     * Triggered when a new message is received.
     *
     * @event Client#onMessage
     * @property {TextMessage} TextMessage - Class with all of the information about received text message
     * @example
     * const bot = new Client("MyBot");
     * bot.on('onMessage', (message) => {
     *   console.log(`Message from ${message.peerName}: ${message.message}`);
     * });
     */
    'onMessage': [textMessage: TextMessage]
    'onFile': [fileMessage: FileMessage]
    'onAudio': [audioMessage: AudioMessage]
    'onIcon': [iconMessage: IconMessage]
    'onError': [error: any]
    'onBotJoinRoom': [currentTopic: string]
}